# Self Service

Sirva-se com as comidas disponíveis:

*que são elas:*

- arroz

- tutu 

- carne

- batata frita

- salada

- farofa

# Sem opção de repetição de alimento

### Como instalar e usar:

```
# Instalação
pip install self-service-game
```

```
# Uso
self-service
```

